# TwitchPy

## Instalation

You have to execute this command:

~~~
pip install twitchpy
~~~

## Getting started

There are some tokens and IDs you will require if you want to use TwitchPy:

+ OAuth Token. Log in to Twitch with your account and visit: <https://twitchapps.com/tmi/>
+ Client ID. Register a Twitch application with your account: <https://dev.twitch.tv/>
+ Client secret. Get a client secret for your Twitch application.
